==> luckybackup-0.3.2.tar.gz: luckybackup-0.3.2/src/manage.cpp <==
/* ---------------------------------- manage.cpp ---------------------------------------------------------------------------
 Class to display the manage backups dialog

===============================================================================================================================
===============================================================================================================================
     This file is part of "luckyBackup" project
     Copyright 2008-2009, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     luckyBackup is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.

 project version	: Please see "main.cpp" for project version

 developer 		: luckyb 
 last modified 		: 25 May 2009
===============================================================================================================================
===============================================================================================================================
*/
#include "manage.h"

// class manageDialog Constructor=================================================================================================
// Displays the manage backups of a task dialog
manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
{

	//first set  variables source & dest
	QString source, dest;
	source = Operation[currentOperation] -> GetSource();
	dest = Operation[currentOperation] -> GetDestination();

	uiG.setupUi(this);
	uiG.treeView_source -> setVisible(FALSE);
	uiG.lineEdit_source -> setVisible(FALSE);
	//connect okay pushButton SLOTs ----------------
	//connect ( uiA.pushButton_ok, SIGNAL( clicked() ), this, SLOT( okay() ) );

	QDirModel *model = new QDirModel;
	uiG.treeView_browser	-> setModel(model);
	uiG.treeView_browser	-> setRootIndex(model->index(source));
	uiG.treeView_source	-> setModel(model);
	uiG.treeView_source	-> setRootIndex(model->index(source));
	uiG.lineEdit_destination -> setText(dest);
	uiG.lineEdit_source	-> setText(source);
	//Operation[currentTask] -> GetDestination()
}
// SLOTS-------------------------------------------------------------------------------------
// --------------------------------okay pressed------------------------------------------------
/*void manageDialog::okay()
{
	close();
}

// FUNCTIONS-------------------------------------------------------------------------------------
void aboutDialog::setTop()
{
	Text = appName+" "+ countStr.setNum(appVersion);
	uiA.label_Top -> setText(Text);
}
void aboutDialog::setAbout()
{
	uiA.textBrowser_About -> setOpenLinks(TRUE);
	uiA.textBrowser_About -> setOpenExternalLinks(TRUE);

	Text = 	"<p align=\"center\"><b>"+appName + " " + countStr.setNum(appVersion) +"</b> ("+
		tr("using Qt4")+")" + "<br>" +
		tr("Backup & Sync Application")+"<br><br>"

		"(C) 2008-2009,	"+
		tr("Loukas Avgeriou") +"<br><br>"

		"web:<br>"
		"<a href=\"http://luckybackup.sourceforge.net/\" target=\"_blank\">http://luckybackup.sourceforge.net/</a> <br>"
		"<a href=\"http://www.kde-apps.org/content/show.php/luckyBackup?content=94391\" target=\"_blank\">http://www.kde-apps.org/</a> <br><br>"

		"<a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\"><img name=\"gpl\""
		" src=\":/luckyPrefix/gplv3-127x51.png\" width=\"60\" height=\"20\" border=\"0\"></a>&nbsp;&nbsp;"+
		tr("luckyBackup is distributed under the terms of the")+
		" <a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\">" +
		tr("GNU General Public License")+".</a>" +"<br><br>" +

		tr("It is <b>free software</b>: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3 of the License.") +"<br>" +
		tr("It is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.")+ "<br>" +
		tr("See the 'License Agreement' tab for more details.")+"</p>";

	uiA.textBrowser_About -> setText(Text);
}
}
*/
// end of manage.cpp ---------------------------------------------------------------------------

==> luckybackup-0.3.3.tar.gz: luckybackup-0.3.3/src/manage.cpp <==
/* ---------------------------------- manage.cpp ---------------------------------------------------------------------------
 Class to display the manage backups dialog

===============================================================================================================================
===============================================================================================================================
     This file is part of "luckyBackup" project
     Copyright 2008-2009, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     luckyBackup is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.

 project version	: Please see "main.cpp" for project version

 developer 		: luckyb 
 last modified 		: 09 July 2009
===============================================================================================================================
===============================================================================================================================
*/
#include "manage.h"

// class manageDialog Constructor=================================================================================================
// Displays the manage backups of a task dialog
manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
{

	//first set  variables source & dest
	QString source, dest;
	source = Operation[currentOperation] -> GetSource();
	dest = Operation[currentOperation] -> GetDestination();

	uiG.setupUi(this);
	uiG.treeView_source -> setVisible(FALSE);
	uiG.lineEdit_source -> setVisible(FALSE);
	//connect cancel pushButton SLOTs ----------------
	connect ( uiG.pushButton_cancel, SIGNAL( clicked() ), this, SLOT( cancel() ) );

	QDirModel *model = new QDirModel;
	uiG.treeView_browser	-> setModel(model);
	uiG.treeView_browser	-> setRootIndex(model->index(source));
	uiG.treeView_source	-> setModel(model);
	uiG.treeView_source	-> setRootIndex(model->index(source));
	uiG.lineEdit_destination -> setText(dest);
	uiG.lineEdit_source	-> setText(source);
	//Operation[currentTask] -> GetDestination()
}
// SLOTS-------------------------------------------------------------------------------------
// --------------------------------cancel pressed------------------------------------------------
void manageDialog::cancel()
{
	close();
}

// FUNCTIONS-------------------------------------------------------------------------------------

// end of manage.cpp ---------------------------------------------------------------------------
